@@ -23,6 +23,7 @@ class ProcessFilter(DexyFilter):
     ALIASES = ['processfilter']
     CHECK_RETURN_CODE = True
     ENV = None
+    TIMEOUT = None
 
     def ignore_errors(self):
         """
@@ -65,6 +66,8 @@ class ProcessFilter(DexyFilter):
         if self.artifact.args.has_key('timeout'):
             timeout = self.artifact.args['timeout']
             self.log.info("using custom timeout %s for %s" % (timeout, self.artifact.key))
+        elif self.TIMEOUT:
+            timeout = self.TIMEOUT
         else:
             timeout = None
         return timeout
